==> haskell-indexed-traversable-instances-0.1.2-124.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-Lkd5OiVpVypLKxZPidfqff
key:                  indexed-traversable-instances-0.1.2-Lkd5OiVpVypLKxZPidfqff
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  54299ecf8110583cc2506b857c1412c3
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-Lkd5OiVpVypLKxZPidfqff

depends:
    OneTuple-0.4.2-6h1VpY4iGdO6wZSCEFOMPx base-4.18.2.1
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-traversable-instances-0.1.2-125-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-HUuqghnVr7GEAUbAb8qitO
key:                  indexed-traversable-instances-0.1.2-HUuqghnVr7GEAUbAb8qitO
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  c4e972ff7e9f81ef5cb224b6a714bc50
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-HUuqghnVr7GEAUbAb8qitO

depends:
    OneTuple-0.4.2-6pEN3mXYu4CEsP59PDdiWd base-4.18.2.1
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
